/*-
 * #%L
 * Smile CDR - CDR
 * %%
 * Copyright (C) 2016 - 2024 Smile CDR, Inc.
 * %%
 * All rights reserved.
 * #L%
 */
package com.example.ips;

import ca.uhn.fhir.jpa.ips.api.ISectionResourceSupplier;
import ca.uhn.fhir.jpa.ips.api.IpsContext;
import ca.uhn.fhir.jpa.ips.api.IpsSectionContext;
import ca.uhn.fhir.rest.api.server.RequestDetails;
import jakarta.annotation.Nullable;
import org.hl7.fhir.r4.model.Communication;
import org.hl7.fhir.r4.model.Reference;
import org.hl7.fhir.r4.model.StringType;

import java.util.List;

public class PatientNotesSectionResourceSupplier implements ISectionResourceSupplier {
	@Nullable
	@Override
	public List<ResourceEntry> fetchResourcesForSection(
			IpsContext theIpsContext, IpsSectionContext theSectionContext, RequestDetails theRequestDetails) {
		// In this example we'll hard code a single resource to pretend
		// we fetched it from somewhere, but we could grab this from any
		// source
		Communication communication = new Communication();
		communication.setId("Communication/1");
		communication.setSubject(new Reference(theIpsContext.getSubjectId()));

		StringType noteContents = new StringType("This is a note");
		communication.addPayload().setContent(noteContents);

		// For each resource being returned, we need to designate it as a "primary"
		// or "secondary" resource. A primary resource is one that is linked to
		// directly from the composition, where a secondary resource is included in
		// the bundle but not directly linked to from the Composition. Typically,
		// this means the resource is linked to from a primary resource.
		ResourceEntry entry = new ResourceEntry(communication, InclusionTypeEnum.PRIMARY_RESOURCE);

		return List.of(entry);
	}
}
